// Persistence of Vision Ray Tracer Scene Description File
// File: .gfx
// Vers: 3
// Desc: A Billards
// Date: 25/07/97
// Auth: Gfx alias Romain GUY

//*********************INCLUDES***************************

#debug "BILLARD @1997 Gfx\n"
#include "gfx.inc"
#include "consts.inc"
#declare Rad_Quality = Radiosity_Final
#include "rad_def.inc"

//*********************CAMERA*****************************

camera {
  location < 0, 5, -4 >
  look_at < 0, 2.2, 1 >
}

//*********************DECLARE TABLE**********************

#declare Table =       //***********INTENSIVE CSG*********
union {
  difference {
    box {
      < -4, 0, 0 >,
      < 4, 2, 16 >
      pigment {
        DMFWood5
      }
      finish {
        ambient 0.3
      }
    }
    
    box {
      < -3.7, 1, 0.3 >,
      < 3.7, 3, 15.7 >
      pigment { DMFWood5 }
    } 
  }

    box {
      < -3.7, 1, 0.3 >,
      < 3.7, 1.7, 15.7 >
      pigment {
        color Green
      }
  }
}

#declare Trous =
  union {
    sphere {
      < -3.4, 1.7, 15.4 >, 0.3
        pigment { color Black }
    }

    sphere {
      < 3.4, 1.7, 15.4 >, 0.3
        pigment { color Black }
    }
  
    sphere {
      < 3.4, 1.7, 8 >, 0.3
        pigment { color Black }
    }

    sphere {
      < -3.4, 1.7, 8 >, 0.3
        pigment { color Black }
    }

    sphere {
      < 3.4, 1.7, 0.6 >, 0.3
        pigment { color Black }
    }

    sphere {
      < -3.4, 1.7, 0.6 >, 0.3
        pigment { color Black }
    }
  }

difference {           //**********THE TABLE**************
  object { Table }
  object { Trous }
}

//*********************THE BALLS**************************

sphere {
  < 0, 1.98, 2 >, 0.28
    pigment {
      color Red
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
      reflection 0.2
    }
}

sphere {
  < 3, 1.98, 10 >, 0.28
    pigment {
      color Green
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
      reflection 0.2
    }
}

sphere {
  < -2, 1.98, 11 >, 0.28
    pigment {
      color Black
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
      reflection 0.2
    }
}

sphere {
  < -3.3, 1.98, 3 >, 0.28
    pigment {
      color Yellow
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
      reflection 0.2
    }
}

sphere {
  < .8, 1.98, 7 >, 0.28
    pigment {
      color Gray
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
      reflection 0.2
    }
}

//*********************DECLARE THE CANE*******************

#declare Manche =
  cylinder {
    < -1.2, 0, 0 >,
    < 4, 0, 0 >,
    0.07
    texture {
      WWood
      scale 0.2
    }
  }

#declare Bout =
  cylinder {
    < 4, 0, 0 >,
    < 4.2, 0, 0 >,
    0.07
    pigment {
      color White
    }
  }

#declare Gomme =
  cylinder {
    < 4.2, 0, 0 >,
    < 4.3, 0, 0 >,
    0.06
    pigment {
      color Blue
    }
    finish {
      crand 0.15
    }
  }

merge {                //**********FIRST CANE*************
  object { Manche }
  object { Bout }
  object { Gomme }
  rotate -45*y
  translate < 1, 2.07, 0 >
}

merge {
  object { Manche }    //**********SECOND CANE************
  object { Bout }
  object { Gomme }
  rotate 90*z
  translate < -2, -2, -0.06 >
}

//*********************THE GROUND*************************

plane {
  < 0, 1, 0 >, -2
  pigment {
    image_map {
      tga
      "parquet.tga"
    }
  scale 2.4
  }
  finish {
    phong 0.3
    reflection 0.3
    phong_size 120
    roughness 0.005
    ambient 0.3
  }
}

//*********************THE WALL***************************

box {
  < -30, -2, 24 >,
  < 30, 50, 24 >
  texture {
    Cork
  }
}

//*********************TABLE 'FEETS'**********************

cylinder {
  < 3.5, 0, 0.5 >,
  < 3.5, -2, 0.5 >,
  0.4
  pigment {
    DMFWood5
  }
}

cylinder {
  < -3.5, 0, 0.5 >,
  < -3.5, -2, 0.5 >,
  0.4
  pigment {
    DMFWood5
  }
}

//*********************AERIAN LAMPE***********************

#declare Lampe =
difference {  
  cone {
    < 0, 0, 0 >, 1.5
    < 0, 1, 0 >, 0
    pigment {
      color Black
    }
  }

  cone {
    < 0, 0, 0 >, 1.4
    < 0, 0.9, 0 >, 0
    pigment {
      color Black
    }
  }
}

object {
  Lampe
  translate < 0, 4, 8 >
}

light_source {
  < 0, 3.9, 8 >
  color White
}

//*********************THE DUKE POSTER********************

box {
  < -16.5, 1, 23.9 >,
  < -4.5, 25, 23.9 >
  pigment {
    image_map {
      tga
      "duke.tga"
    }
  scale < 12, 20, 1 >
  translate < -4.5, -0.2, 0 >
  }
  no_shadow
}

//*********************THE DUKE GAME**********************

#declare Borne_Arcade =//**********X-TREME INTENSIVE CSG**
merge {
  box {                //**********BODY*******************
    < -1, 1.5, 0 >,
    < 1, 4, 2 >
    texture {
      Gold_Metal
    }
  }
  difference {
    box {
      < -1, 4, 1 >,
      < 1, 5.7, 2 >
      texture {
        Gold_Metal
      }
    }
    box {
      < -0.95, 4.1, 0.9 >,
      < 0.95, 5.6, 1.5 >
      texture {
        Gold_Metal
      }
    }
  }
  box {                //**********THE GAME***************
    < -0.95, 4.1, 0.9 >,
    < 0.95, 5.6, 1.5 >
    pigment {
      image_map {
        tga
        "arcade.tga"
    }
    scale < 1.9, 1.5, 1 >
    translate < 0.95, 1.1, 0 >
   }
  }
  box {
    < -1, 5.7, 0.3 >,
    < 1, 6, 2 >
    texture {
      Gold_Metal
    }
  }
  merge {              //**********THE JOYSTICK***********
    cylinder {
      < 0, 0, 0 >,
      < 0, 1, 0 >,
      0.2
    }
    sphere {
      < 0, 1.5, 0 >, 0.5
    }
    texture {
      pigment {
        color Red
      }
      finish {
        crand 0.2
      }
    }
    scale 0.15
    translate < -0.6, 4, 0.3 >
  }
  cylinder {           //**********THE BUTTONS************
    < 0.6, 4, 0.4 >,
    < 0.6, 4.04, 0.4 >,
    0.08
    pigment {
      color Green
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
    } 
  }
  cylinder {
    < 0.42, 4, 0.4 >,
    < 0.42, 4.04, 0.4 >,
    0.08
    pigment {
      color Blue
    }
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
    }
  }
  cylinder {
    < 0.24, 4, 0.4 >,
    < 0.24, 4.04, 0.4 >,
    0.08
    pigment {
      color Red
    }  
    finish {
      ambient 0.3
      diffuse 0.90
      phong 1.00
      phong_size 35.0
    }
  }
  difference {         //**********INSERT COIN PLACE******
    box {
      < 0, 0, 0 >,
      < 1, 2, 0.1 >
      texture {
        Chrome_Metal
      }
    }
    union {
      box {
        < 0.45, 1.2, 0 >,
        < 0.55, 1.7, 0.1 >
        pigment {
          color Black
        }
      }
      box {
        < 0.45, 0.2, 0 >,
        < 0.55, 0.7, 0.1 >
        pigment {
          color Black
        } 
      } 
      scale 0.2
      translate < -0.7, 3.4, -0.01 >
    }
  }
}

object {               //**********WHO!! THIS IS THE END**
  Borne_Arcade
  scale < 1.2, 0.85, 1 >
  translate -0.5*y
  translate 19*z
  translate 5*x
}

//end of file
